@@ -39,6 +39,32 @@ $GLOBALS['LSobjects']['LSpeople'] = array (
       'ou' => 'people'
     )
   ),
+
+  'ioFormat' => array (
+    'mycsv' => array (
+      'label' => 'Simple CSV',
+      'driver' => 'CSV',
+      'driver_options' => array (
+        'delimiter' => ';',
+        'escape' => '"',
+        'eol' => ';',
+        'length' => 2
+      ),
+      'fields' => array (
+        'login' => 'uid',
+        'civility' => 'personalTitle',
+        'firstname' => 'givenName',
+        'name' => 'sn',
+        'mail' => 'mail',
+        'password' => 'userPassword',
+        'gid' => 'gidNumber',
+        'shell' => 'loginShell',
+      ),
+      'generated_fields' => array (
+        'cn' => '%{personalTitle} %{givenName} %{sn}'
+      )
+    )
+  ),
   
   'before_modify' => 'valid',
   'after_modify' => 'valid',
@@ -143,6 +169,12 @@ $GLOBALS['LSobjects']['LSpeople'] = array (
     'predefinedFilters' => array (
       '(jpegPhoto=*)' => 'With photo',
       '(!(jpegPhoto=*))' => 'Without photo'
+    ),
+    'extraDisplayedColumns' => array (
+      'mail' => array (
+        'label' => 'Mail',
+        'LSformat' => '%{mail}'
+      ),
     )
   ),
   
@@ -228,9 +260,10 @@ $GLOBALS['LSobjects']['LSpeople'] = array (
       'required' => 1,
       'default_value' => 'toto',
       'check_data' => array (
-        'alphanumeric' => array(
-          'msg' => 'The first name must contain alphanumeric values only.'
-        ),
+          'alphanumeric' => array(
+              'params' => array('withAccents' => true),
+              'msg' => 'The first name must contain alphanumeric values only.'
+          ),
       ),
       'rights' => array(
         'self' => 'r',
@@ -299,21 +332,27 @@ $GLOBALS['LSobjects']['LSpeople'] = array (
       'html_type' => 'select_list',
       'html_options' => array (
         'possible_values' => array(
-          'OTHER_OBJECT' => array(
-            'object_type' => 'LSgroup',                      // Nom de l'objet à lister
-            'display_name_format' => '%{cn} (%{gidNumber})',   // Spécifie le attributs à lister pour le choix,
-                                                               // si non définie => utilisation du 'display_name_format'
-                                                               // de la définition de l'objet
-                                                
-            'value_attribute' => 'gidNumber',   // Spécifie le attributs dont la valeur sera retournée par
-            /*'filter' =>                         // le formulaire spécifie les filtres de recherche pour
-              array (                           // l'établissement de la liste d'objets :
-                array(                          // Premier filtre
-                  'filter' => 'cn=*a*',
-                  //'basedn' => 'o=company',
-                  'scope' => 'sub',
-                )
-              )*/
+          '0' => 'No group',
+          array (
+            'label' => 'LDAP Groups',
+            'possible_values' => array (
+              'OTHER_OBJECT' => array (
+              'object_type' => 'LSgroup',                      // Nom de l'objet à lister
+              'display_name_format' => '%{cn} (%{gidNumber})',   // Spécifie le attributs à lister pour le choix,
+                                                                 // si non définie => utilisation du 'display_name_format'
+                                                                 // de la définition de l'objet
+
+              'value_attribute' => 'gidNumber',   // Spécifie le attributs dont la valeur sera retournée par
+              /*'filter' =>                         // le formulaire spécifie les filtres de recherche pour
+                array (                           // l'établissement de la liste d'objets :
+                  array(                          // Premier filtre
+                    'filter' => 'cn=*a*',
+                    //'basedn' => 'o=company',
+                    'scope' => 'sub',
+                  )
+                )*/
+              )
+            )
           )
         )
       ),
@@ -507,7 +546,14 @@ $GLOBALS['LSobjects']['LSpeople'] = array (
           'msg' => 'Your password must contain from 8 to 10 characters.',
           'params' => array(
             'minLength' => 8,
-            'maxLength' => 10
+            'maxLength' => 10,
+            'regex' => array (
+              '/[A-Z]/',
+              '/[a-z]/',
+              '/[0-9]/',
+              '/[^A-Za-z0-9]/',
+            ),
+            'minValidRegex' => 3
           )
         )
       ),
