@@ -39,7 +39,7 @@ class LSldap {
    *
    * @author Benjamin Renard <brenard@easter-eggs.com>
    *
-   * @param[in] $config array Tableau de configuration au formar Net_LDAP2
+   * @param[in] $config array Tableau de configuration au format Net_LDAP2
    *
    * @retval void
    */
@@ -48,15 +48,15 @@ class LSldap {
   }
   
   /**
-   * Connection
+   * Connect to LDAP server
    *
-   * Cette methode établie la connexion à l'annuaire Ldap
+   * This method  establish connection to LDAP server
    *
    * @author Benjamin Renard <brenard@easter-eggs.com>
    * 
-   * @param[in] $config array Tableau de configuration au formar Net_LDAP2
+   * @param[in] $config array LDAP configuration array in format of Net_LDAP2
    *
-   * @retval boolean true si la connection est établie, false sinon
+   * @retval boolean true if connected, false instead
    */
   public static function connect($config = null) {
     if ($config) {
@@ -71,6 +71,36 @@ class LSldap {
     return true;
   }
   
+  /**
+   * Reconnect (or connect) with other credentials
+   *
+   * @author Benjamin Renard <brenard@easter-eggs.com>
+   *
+   * @param[in] $dn string Bind DN
+   * @param[in] $pwd array Bind password
+   * @param[in] $config array LDAP configuration array in format of Net_LDAP2
+   *
+   * @retval boolean true if connected, false instead
+   */
+  public static function reconnectAs($dn,$pwd,$config) {
+    if ($config) {
+      self :: setConfig($config);
+    }
+	if (self :: $cnx) {
+	  self :: $cnx -> done();
+	}
+	$config=self :: $config;
+	$config['binddn']=$dn;
+	$config['bindpw']=$pwd;
+	self :: $cnx = Net_LDAP2::connect($config);
+	if (Net_LDAP2::isError(self :: $cnx)) {
+	  LSerror :: addErrorCode('LSldap_01',self :: $cnx -> getMessage());
+	  self :: $cnx = NULL;
+	  return;
+	}
+	return true;
+  }
+
   /**
    * Déconnection
    *
@@ -282,14 +312,14 @@ class LSldap {
         $drop = true;
         if (is_array($attrVal)) {
           foreach($attrVal as $val) {
-            if (!empty($val)) {
+            if (!empty($val)||(is_string($val)&&($val=="0"))) {
               $drop = false;
               $changeData[$attrName][]=$val;
             }
           }
         }
         else {
-          if (!empty($attrVal)) {
+          if (!empty($attrVal)||(is_string($attrVal)&&($attrVal=="0"))) {
             $drop = false;
             $changeData[$attrName][]=$attrVal;
           }
@@ -422,7 +452,12 @@ class LSldap {
   public static function combineFilters($op,$filters,$asStr=false) {
     if (is_array($filters) && !empty($filters)) {
       if (count($filters)==1) {
-        return $filters[0];
+        if ($asStr && $filters[0] instanceof Net_LDAP2_Filter) {
+          return $filters[0]->asString();
+        }
+        else {
+          return $filters[0];
+        }
       }
       $filter=Net_LDAP2_Filter::combine($op,$filters);
       if (!Net_LDAP2::isError($filter)) {
