@@ -39,7 +39,6 @@ class LSldapObject {
   var $dn=false;
   var $oldDn=false;
   var $other_values=array();
-  var $submitError=true;
   var $_whoami=NULL;
   var $_LSrelationsCache=array();
 
@@ -277,15 +276,21 @@ class LSldapObject {
   }
   
   /**
-   * Met Ã  jour les donnÃ©es de l'objet Ã  partir d'un retour d'un formulaire.
+   * Update LDAP object data from one form specify by it's ID.
    *
-   * @param[in] $idForm Identifiant du formulaire d'origine
+   * This method just valid form ID, extract form data and call
+   * _updateData() private method.
+   *
+   * @param[in] $idForm Form ID
+   * @param[in] $justValidate Boolean to enable just validation mode
+   *
+   * @see _updateData()
    *
    * @author Benjamin Renard <brenard@easter-eggs.com>
    *
-   * @retval boolean true si la mise Ã  jour a rÃ©ussi, false sinon
+   * @retval boolean true if object data was updated, false otherwise
    */ 
-  public function updateData($idForm=NULL) {
+  public function updateData($idForm=NULL,$justValidate=False) {
     if($idForm!=NULL) {
       if(isset($this -> forms[$idForm]))
         $LSform = $this -> forms[$idForm][0];
@@ -308,22 +313,28 @@ class LSldapObject {
       }
     }
     $new_data = $LSform -> exportValues();
-    return $this -> _updateData($new_data,$idForm);
+    return $this -> _updateData($new_data,$idForm,$justValidate);
   }
 
   /**
-   * Met Ã  jour les donnÃ©es de l'objet et de l'entrÃ© de l'annuaire
+   * Update LDAP object data from one form specify by it's ID.
+   *
+   * This method implement the continuation and the end of the object data
+   * udpate.
    * 
-   * @param[in] $new_data Tableau des données de modification de l'objet
+   * @param[in] $new_data Array of object data
+   * @param[in] $idForm Form ID
+   * @param[in] $justValidate Boolean to enable just validation mode
    *
    * @author Benjamin Renard <brenard@easter-eggs.com>
    *
-   * @retval boolean true si la mise Ã  jour a rÃ©ussi, false sinon
+   * @retval boolean true if object data was updated, false otherwise
    *
+   * @see updateData()
    * @see validateAttrsData()
    * @see submitChange()
    */ 
-  private function _updateData($new_data,$idForm=null) {
+  private function _updateData($new_data,$idForm=null,$justValidate=False) {
     if(!is_array($new_data)) {
       return;
     }
@@ -334,6 +345,10 @@ class LSldapObject {
     }
     if($this -> validateAttrsData($idForm)) {
       LSdebug("les données sont validées");
+      if ($justValidate) {
+        LSdebug('Just validate mode');
+        return True;
+      }
       
       if (!$this -> fireEvent('before_modify')) {
         return;
@@ -349,9 +364,7 @@ class LSldapObject {
       if ($this -> submitChange($idForm)) {
         LSdebug('Les modifications sont submitÃ©es');
         // Event After Modify
-        if(!$this -> submitError) {
-          $this -> fireEvent('after_modify');
-        }
+        $this -> fireEvent('after_modify');
 
         // $this -> attrs[*] => After Modify
         foreach($new_data as $attr_name => $attr_val) {
@@ -359,7 +372,6 @@ class LSldapObject {
             $this -> attrs[$attr_name] -> fireEvent('after_modify');
           }
         }
-        $this -> submitError = false;
         $this -> reloadData();
         $this -> refreshForm($idForm);
       }
@@ -462,19 +474,21 @@ class LSldapObject {
           if((isset($test['filter'])||isset($test['basedn']))&&(isset($test['result']))) {
             $sparams=(isset($test['scope']))?array('scope' => $test['scope']):array();
             $this -> other_values['val']=$val;
-            $sfilter_user=(isset($test['filter']))?getFData($test['filter'],$this,'getValue'):NULL;
-            if(isset($test['object_type'])) {
-              $test_obj = new $test['object_type']();
-              $sfilter=$test_obj->getObjectFilter();
-	      if ($sfilter_user) {
-                $sfilter='(&'.$sfilter;
-                if($sfilter_user[0]=='(') {
-                  $sfilter=$sfilter.$sfilter_user.')';
-                }
-                else {
-                  $sfilter=$sfilter.'('.$sfilter_user.'))';
-                }
-	      }
+            // Filter from test configuration
+            if (isset($test['filter']) && !empty($test['filter'])) {
+              $sfilter_user=getFData($test['filter'],$this,'getValue');
+              if ($sfilter_user[0]!='(') $sfilter_user="(".$sfilter_user.")";
+              $sfilter_user=Net_LDAP2_Filter::parse($sfilter_user);
+            }
+            else {
+              $sfilter_user=NULL;
+            }
+            if(isset($test['object_type']) && LSsession :: loadLSobject($test['object_type']) ) {
+              $sfilter=self :: getObjectFilter($test['object_type']);
+
+              if ($sfilter_user) {
+                $sfilter=LSldap::combineFilters('and',array($sfilter_user,$sfilter));
+              }
             }
             else {
               $sfilter=$sfilter_user;
@@ -663,7 +677,7 @@ class LSldapObject {
    *
    * @author Benjamin Renard <brenard@easter-eggs.com>
    *
-   * @retval string le filtre ldap correspondant au type de l'objet
+   * @retval Net_LDAP2_Filter le filtre ldap correspondant au type de l'objet
    */ 
   function getObjectFilter($type=null) {
     if (is_null($type)) {
@@ -678,10 +692,10 @@ class LSldapObject {
     
     $filter=LSconfig::get("LSobjects.$type.filter");
     if ($filter) {
-      $filters[]=$filter;
+      $filters[]=Net_LDAP2_Filter::parse($filter);
     }
 
-    $filter = LSldap::combineFilters('and',$filters,true);
+    $filter = LSldap::combineFilters('and',$filters);
     if ($filter)
       return $filter;
     LSerror :: addErrorCode('LSldapObject_30',$type);
@@ -867,7 +881,7 @@ class LSldapObject {
       return $this -> dn;
     }
     else if(($val=='rdn')||($val=='%{rdn}')) {
-      return $this -> attrs[ $this -> config['rdn'] ] -> getValue();
+      return $this -> rdn;
     }
     else if(($val=='subDn')||($val=='%{subDn}')) {
       return $this -> subDnValue;
@@ -1654,7 +1668,7 @@ class LSldapObject {
    */
   function addObjectEvent($event,&$obj,$meth,$param=NULL) {
     $this -> _objectEvents[$event][] = array(
-      'obj'  => $obj,
+      'obj'  => &$obj,
       'meth'  => $meth,
       'param'    => $param
     );
@@ -1807,13 +1821,48 @@ class LSldapObject {
       $this -> cache['subDnValue'] = self :: getSubDnValue($this -> dn);
       return $this -> cache['subDnValue'];
     }
-    if ($key=='subDnName') {
+    elseif ($key=='subDnName') {
       if ($this -> cache['subDnName']) {
         return $this -> cache['subDnName'];
       }
       $this -> cache['subDnName'] = self :: getSubDnName($this -> dn);
       return $this -> cache['subDnName'];
     }
+    elseif ($key=='rdn') {
+      if ($this -> config['rdn'] && isset($this -> attrs[ $this -> config['rdn'] ])) {
+        return $this -> attrs[ $this -> config['rdn'] ] -> getValue();
+      }
+      return false;
+    }
+  }
+
+  /**
+   * List IOformats of this object type
+   *
+   * @retval mixed Array of valid IOformats of this object type
+   **/
+  function listValidIOformats() {
+    $ret=array();
+    if (isset($this -> config['ioFormat']) && is_array($this -> config['ioFormat'])) {
+      foreach($this -> config['ioFormat'] as $name => $conf) {
+        $ret[$name]=_((isset($conf['label'])?$conf['label']:$name));
+      }
+    }
+    return $ret;
+  }
+
+  /**
+   * Check if an IOformat is valid for this object type
+   *
+   * @param[in] $f string The IOformat name to check
+   *
+   * @retval boolean True if it's a valid IOformat, false otherwise
+   **/
+  function isValidIOformat($f) {
+    if (isset($this -> config['ioFormat']) && is_array($this -> config['ioFormat']) && isset($this -> config['ioFormat'][$f])) {
+      return True;
+    }
+    return False;
   }
   
 }
