@@ -60,7 +60,8 @@ class LSsearch {
     'nbObjectsByPage' => NB_LSOBJECT_LIST,
     'nbPageLinkByPage' => 10,
     'customInfos' => array(),
-    'withoutCache' => false
+    'withoutCache' => false,
+    'extraDisplayedColumns' => false,
   );
   
   // The cache of search parameters
@@ -365,7 +366,7 @@ class LSsearch {
     
     // Sort By
     if (isset($params['sortBy']) && is_string($params['sortBy'])) {
-      if (in_array($params['sortBy'],array('displayName','subDn'))) {
+      if (in_array($params['sortBy'],array('displayName','subDn')) || ($this ->extraDisplayedColumns && isset($this ->extraDisplayedColumns[$params['sortBy']]))) {
         if ($this -> params['sortBy'] == $params['sortBy']) {
           $this -> toggleSortDirection();
         }
@@ -452,6 +453,11 @@ class LSsearch {
       }
     }
 
+    // Extra Columns
+    if (isset($params['extraDisplayedColumns'])) {
+      $this -> params['extraDisplayedColumns']=(bool)$params['extraDisplayedColumns'];
+    }
+
     // predefinedFilter
     if (isset($params['predefinedFilter'])) {
       if (is_string($params['predefinedFilter'])) {
@@ -788,6 +794,31 @@ class LSsearch {
     else {
       $retval['attributes']=$attrs;
     }
+
+    // Extra Columns
+    if ($this -> params['extraDisplayedColumns'] && is_array($this -> config['extraDisplayedColumns'])) {
+      foreach ($this -> config['extraDisplayedColumns'] as $id => $conf) {
+        $attrs=getFieldInFormat($conf['LSformat']);
+        if(is_array($conf['alternativeLSformats'])) {
+          foreach ($conf['alternativeLSformats'] as $format) {
+            $attrs=array_merge($attrs,getFieldInFormat($format));
+          }
+        }
+        else {
+          $attrs=array_merge($attrs,getFieldInFormat($conf['alternativeLSformats']));
+        }
+        if(is_array($retval['attributes'])) {
+          $retval['attributes']=array_merge($attrs,$retval['attributes']);
+        }
+        else {
+          $retval['attributes']=$attrs;
+        }
+      }
+    }
+
+    if (is_array($retval['attributes'])) {
+      $retval['attributes']=array_unique($retval['attributes']);
+    }
     
     $this -> _searchParams = $retval;
   }
@@ -980,6 +1011,7 @@ class LSsearch {
    **/
   public function __get($key) {
     $params = array (
+      'basedn',
       'sortBy',
       'sortDirection'
     );
@@ -1042,6 +1074,14 @@ class LSsearch {
 			}
       return $retval;
     }
+    elseif ($key=='extraDisplayedColumns') {
+      if ($this->params['extraDisplayedColumns'] && is_array($this -> config['extraDisplayedColumns'])) {
+        return $this -> config['extraDisplayedColumns'];
+      }
+      else {
+        return False;
+      }
+    }
     else {
       throw new Exception('Incorrect property !');
     }
@@ -1059,10 +1099,10 @@ class LSsearch {
     $sortBy = $this -> params['sortBy'];
     $sortDirection = $this -> params['sortDirection'];
     if ($sortDirection=='ASC') {
-      $dir = -1;
+      $dir = 1;
     }
     else {
-      $dir = 1;
+      $dir = -1;
     }
     $oa = new LSsearchEntry($this,$this -> LSobject,$this -> params,$this -> _hash,$this -> result['list'],$a);
     $va = $oa->$sortBy;
@@ -1071,13 +1111,8 @@ class LSsearch {
     
     if ($va == $vb) return 0;
     
-    $val = array($va,$vb);
-    sort($val);
-    
-    if ($val[0]==$va)
-      return 1*$dir;
-      
-    return -1*$dir;
+    $val = strcoll(strtolower($va), strtolower($vb));
+    return $val*$dir;
   }
   
   /**
@@ -1280,5 +1315,6 @@ _("LSsearch : The function of the custum information %{name} is not callable.")
 LSerror :: defineError('LSsearch_15',
 _("LSsearch : Invalid predefinedFilter for LSobject type %{type} : %{label} (filter : %{filter}).")
 );
-
-?>
+LSerror :: defineError('LSsearch_16',
+_("LSsearch : Error during execution of the custom action %{customAction}.")
+);
