@@ -122,19 +122,42 @@ if (loadDir('../'.LS_OBJECTS_DIR) && loadDir('../'.LS_LOCAL_DIR.LS_OBJECTS_DIR))
         add($lay);
       }
     }
+    if (is_array($conf['LSsearch']['extraDisplayedColumns'])) {
+      foreach($conf['LSsearch']['extraDisplayedColumns'] as $cid => $cconf) {
+        add($cconf['label']);
+      }
+    }
+    if (is_array($conf['LSsearch']['customActions'])) {
+      foreach($conf['LSsearch']['customActions'] as $act) {
+        add($act['label']);
+        add($act['question_format']);
+        add($act['onSuccessMsgFormat']);
+      }
+    }
+
 
     
     if(is_array($conf['attrs'])) {
       foreach($conf['attrs'] as $attr) {
         add($attr['label']);
         add($attr['help_info']);
+        add($attr['no_value_label']);
         add($attr['html_options']['mail']['subject']);
         add($attr['html_options']['mail']['msg']);
         
         // LSattr_html_select_list
-        if ($attr['html_type']=='select_list' && is_array($attr['html_options']['possible_values']) && !$withoutselectlist) {
+        if (($attr['html_type']=='select_list' || $attr['html_type']=='select_box') && is_array($attr['html_options']['possible_values']) && !$withoutselectlist) {
           foreach($attr['html_options']['possible_values'] as $pkey => $pname) {
-            if ($pkey != 'OTHER_OBJECT') {
+            if (is_array($pname)) {
+              add($pname['label']);
+              if (is_array($pname['possible_values'])) {
+                foreach($pname['possible_values'] as $pk => $pn) {
+                  if ($pk == 'OTHER_OBJECT') continue;
+                  add($pn);
+                }
+              }
+            }
+            elseif ($pkey != 'OTHER_OBJECT') {
               add($pname);
             }
           }
@@ -165,6 +188,40 @@ if (loadDir('../'.LS_OBJECTS_DIR) && loadDir('../'.LS_LOCAL_DIR.LS_OBJECTS_DIR))
   }
 }
 
+/*
+ * Manage template file
+ */
+
+function parse_template_file($file) {
+  foreach(file($file) as $line) {
+    if (preg_match_all('/\{ *tr +msg=["\']([^\}]+)["\'] *\}/',$line,$matches)) {
+      foreach($matches[1] as $t)
+        add($t);
+    }
+  }
+}
+
+function find_and_parse_template_file($dir) {
+  if (is_dir($dir)) {
+    if ($dh = opendir($dir)) {
+      while (($file = readdir($dh)) !== false) {
+        if ($file=='.' || $file=='..') continue;
+        if (is_dir($dir.'/'.$file)) {
+          find_and_parse_template_file($dir.'/'.$file);
+        }
+        elseif (is_file($dir."/".$file) && preg_match('/\.tpl$/',$file)) {
+          parse_template_file($dir.'/'.$file);
+        }
+      }
+      closedir($dh);
+    }
+  }
+}
+
+find_and_parse_template_file('../'.LS_TEMPLATES_DIR);
+find_and_parse_template_file('../'.LS_LOCAL_DIR.LS_TEMPLATES_DIR);
+
+
 ksort($data);
 
 echo "<?php\n\n";
